import { Image, Text, View, StyleSheet, Button, BackHandler } from "react-native";
import { FullPageLoader } from "../../common/components/full_page_loader";
import { ApiRequestStatus } from "../../constants/api_request_states";
import { useGetActivityPoint } from "../../hooks/useGetActivityPoint";
import { ScrollView } from "react-native-gesture-handler";
import { AudioPlayer } from "../../common/components/audio_player";
import { FloatingBackButton } from "../../components/floating_back_button/floating_back_button";
import { TouchableOpacity } from "@gorhom/bottom-sheet";
import { LIGTHT_THEME } from "../../constants/theme";
import { router, useFocusEffect } from "expo-router";
import { useAudio } from "../../contexts/audio_context";
import { useEffect } from "react";

interface ActivityPointScreenProps {
  stateId: number;
  townId: number;
  activityId: number;
  id: number;
}

export const ActivityPointScreen = ({
  stateId,
  townId,
  activityId,
  id,
}: ActivityPointScreenProps) => {
  const { data, requestStatus } = useGetActivityPoint({
    activityId,
    townId,
    stateId,
    placeNumber: id,
  });

  const { onUnmount } = useAudio();

  console.log('render')

  useEffect(() => {
    const backAction = () => {
      onUnmount();
      router.back();
      return true;
    }

    const backHandler = BackHandler.addEventListener('hardwareBackPress', backAction);

    return () => backHandler.remove();
  }, []);

  if (requestStatus === ApiRequestStatus.LOADING) {
    return <FullPageLoader />;
  }

  if (requestStatus === ApiRequestStatus.ERROR || !data) {
    return null;
  }

  return (
    <View style={styles.container}>
      <View style={styles.placeContainer}>
        <Text style={styles.title}>{data.name}</Text>
        <View style={styles.imageContainer}>
          <Image
            source={{ uri: data.imageUrl }}
            style={styles.image}
            resizeMode="contain"
          />
        </View>
        <ScrollView contentContainerStyle={{alignItems: "center", paddingVertical: 20}}>
          <Text style={styles.contentText}>{data.content.content}</Text>
          <View style={{ height: 30 }} />
          {!data.directions && (
            <TouchableOpacity style={styles.endActivityButton}>
              <Text style={styles.endActivityButtonText}>End Activity</Text>
            </TouchableOpacity>
          )}
        </ScrollView>
      </View>
      <AudioPlayer
      />
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    gap: 15,
    justifyContent: "space-between",
  },
  placeContainer: {
    flex: 1,
    gap: 20,
    padding: 20,
    alignItems: "center",
  },
  title: {
    fontSize: 24,
    fontWeight: "400",
    textAlign: "center",
  },
  contentText: {
    fontSize: 18,
    lineHeight: 30,
    textAlign: "justify",
  },
  imageContainer: {
    width: "100%",
    height: 300,
    backgroundColor: "lightgrey",
    padding: 10,
    borderRadius: 10,
    overflow: "hidden",
    borderWidth: 2,
  },
  image: {
    height: "70%",
    width: "70%",
  },
  endActivityButton: {
    backgroundColor: LIGTHT_THEME.color.primary,
    padding: 10,
    borderRadius: 25,
    alignItems: "center",
    justifyContent: "center",
    width: 200,
    height: 50
  },
  endActivityButtonText: {
    color: LIGTHT_THEME.color.white,
    fontWeight: "bold",
    fontSize: 16,
  }
});
