import { faWindowClose, faLanguage } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import './css/styles.css'
import { ImageDropzone } from "../../image_dropzone/image_dropzone";
import { Dispatch, SetStateAction, useState } from "react";
import { useTownRegister } from "../../../hooks/useTownRegister";

interface props {
  setWindowActive: Dispatch<SetStateAction<boolean>>,
  setShowRegisterPanel: Dispatch<SetStateAction<boolean>>
}

export const SuperadminPanelTownRegister = ({setWindowActive, setShowRegisterPanel}:props) => {
  const {
    statesList,
    register, 
    setValue,
    handleSubmit, 
    errors, 
    onSubmit
  } = useTownRegister();
  const [isEnglish, setIsEnglish] = useState(false);
  const [spanishDescription, setSpanishDescription] = useState("");
  const [englishDescription, setEnglishDescription] = useState("");

  return (
    <div className="town_register_wrap">
      <div className="town_register_header">
        Registra el pueblo mágico
        <FontAwesomeIcon icon={faWindowClose} className="town_register_close_btn"
          onClick={() => {setShowRegisterPanel(false); setWindowActive(false)}}/>
      </div>
      <div className="town_register_content">
        <form onSubmit={handleSubmit(onSubmit)}>
          <div className="town_name_state_input">
            <div className="language_change_cnt">
              <label>
                {isEnglish ?
                  "Inglés"
                :
                  "Español"
                }
              </label>
              <FontAwesomeIcon icon={faLanguage}
                className="change_lang_btn" 
                onClick={ () =>
                  setIsEnglish(!isEnglish)
                }
              />
            </div>
            <div className="town_name_input">
              <label className="form_label">Nombre del pueblo mágico</label>
              <input className="form_input" 
                type="text"
                {...register('name')}
                required/>
            </div>
            <div className="state_select">
              <label>Estado al que pertenece el pueblo</label>
              {statesList == null ? 
                <label>No hay estados</label>
              : 
                <select
                  {...register('state')}
                  required>
                  {statesList.map((state) => {
                    return (
                      <option key={state.stateId} value={state.stateId}>{state.name}</option>
                    );
                  })}
                </select>
              }
            </div>
          </div>
          <div className="town_description_image_cont">
            <div className="town_desc">
              <div>Descripción del pueblo mágico</div>
              <div className="towm_desc_input_cnt">
                {
                  isEnglish ?
                  <textarea id="0" className="town_desc_textarea"
                    value={englishDescription}
                    {...register('descriptionEN',{
                      onChange(event) {
                        setEnglishDescription(event.target.value);
                      },
                    })}
                    required/>
                  :
                  <textarea id="1" className="town_desc_textarea"
                  value={spanishDescription}
                  {...register('descriptionES',{
                    onChange(event) {
                      setSpanishDescription(event.target.value);
                    },
                  })}
                  required/>
                }
              </div>
            </div>
            <div className="image_container">
              <div>Fotografía representativa del pueblo</div>
              <ImageDropzone setValue={setValue}/>
              <input type="submit"/>
            </div>
          </div>
        </form>
      </div>
    </div>  
  );
}